@@ -7,7 +7,7 @@ test -z "$srcdir" && srcdir=.
 PKG_NAME="totem-pl-parser"
 REQUIRED_M4MACROS=introspection.m4
 
-(test -f $srcdir/configure.in) || {
+(test -f $srcdir/configure.ac) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level $PKG_NAME directory"
     exit 1
